#
# spec file for package libfsntfs
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%{?sle15_python_module_pythons}

%define lname	libfsntfs1
Name:           libfsntfs
Version:        20230606
Release:        2.1
Summary:        Library and tools to access the NTFS filesystem
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libfsntfs
Source:         https://github.com/libyal/libfsntfs/releases/download/%version/libfsntfs-experimental-%version.tar.gz
Source2:        https://github.com/libyal/libfsntfs/releases/download/%version/libfsntfs-experimental-%version.tar.gz.asc
Source3:        %name.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse) >= 2.6
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20230108
BuildRequires:  pkgconfig(libcerror) >= 20220101
BuildRequires:  pkgconfig(libcfile) >= 20220106
BuildRequires:  pkgconfig(libclocale) >= 20221218
BuildRequires:  pkgconfig(libcnotify) >= 20220108
BuildRequires:  pkgconfig(libcpath) >= 20220108
BuildRequires:  pkgconfig(libcsplit) >= 20220109
BuildRequires:  pkgconfig(libcthreads) >= 20220102
BuildRequires:  pkgconfig(libfcache) >= 20230115
BuildRequires:  pkgconfig(libfdata) >= 20220113
BuildRequires:  pkgconfig(libfdatetime) >= 20220112
BuildRequires:  pkgconfig(libfguid) >= 20220113
BuildRequires:  pkgconfig(libfusn) >= 20220119
BuildRequires:  pkgconfig(libfwnt) >= 20220922
BuildRequires:  pkgconfig(libhmac) >= 20230407
BuildRequires:  pkgconfig(libuna) >= 20220611
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
Library and tools to access the New Technology File System (NTFS).

Note that this project currently only focuses on the analysis of the format.

%package -n %lname
Summary:        Library to access the New Technology File System (NTFS)
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
libfsntfs is a library to access the New Technology File System (NTFS).

Note that this project currently only focuses on the analysis of the format.

%package tools
Summary:        Tools to access the New Technology File System (NTFS)
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
libfsntfs-tools is a project to access the NTFS filesystem

Note that this project currently only focuses on the analysis of the format.

%package devel
Summary:        Development files for libfsntfs
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
%name is a library to access the New Technology File System (NTFS).

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%prep
%autosetup -p1

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv "%_builddir/rt"/* %buildroot/
find %buildroot -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libfsntfs.so.*

%files -n %name-tools
%_bindir/fsntfs*
%_mandir/man1/fsntfsinfo.1*

%files -n %name-devel
%_includedir/libfsntfs.h
%_includedir/libfsntfs/
%_libdir/libfsntfs.so
%_libdir/pkgconfig/libfsntfs.pc
%_mandir/man3/libfsntfs.3*

%files %python_files
%license COPYING*
%python_sitearch/pyfsntfs.so

%changelog
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Thu Jun  8 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230606
  * Updates to format support and documentation
* Mon May  1 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20230427
  * No changelog was provided
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Sun Oct 23 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221023
  * No changelog was provided.
* Mon Aug 29 2022 Jan Engelhardt <jengelh@inai.de>
- Update build requirement on libcfile
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Sun Feb 20 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220220
  * No changelog available.
* Sat Jan 22 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds.
* Wed Dec 29 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20211229
  * Unspecified tool updates, unspecified Python binding updates
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to tag 20211023
  * Changes to handle sparse data runs of bitmap attributes
  * Added check for total data runs size
* Thu May 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210503 (8803365c)
  * No changelog was provided
- Add system-libs.patch
- Enable FUSE integration
* Fri Nov 13 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201027
  * worked format support
  * worked on Python bindings
  * changes to handle resident data
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Sun Apr  5 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20200223
  * the codebase has seen significant rework and improvements
  * improved format support
  * improved documentation
  * improved python binding
  * worked on mount tool
  * worked on WofCompressedData format
  * worked on casesensitive support
  * added namespace API function
* Mon Apr 15 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20190104
  * improvments to handle corrupt file systems
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libfsntfs to python2-libfsntfs as expected by singlespec
- remove Provides pyfsntfs as it is not versioned
* Thu Feb 16 2017 Greg.Freemyer@gmail.com
- use internal version of libfdata and libfcache.
  * New releases broke libfsntfs compiles.
- change RPM Group for python binding to development/languages/python
* Thu Jul 28 2016 Greg.Freemyer@gmail.com
- update to v0~20160418
  * Worked on security descriptor support
  * worked on Python bindings
  * worked on Python 3 support
  * 2016 update
- use libcstring, libfdata from factory again
- add python3 binding subpackage
* Wed Feb  3 2016 Greg.Freemyer@gmail.com
- use internal libfdata.  Builds began failing with the recent update of numerous libyal packages
- run through spec-cleaner
* Tue Jan 26 2016 Greg.Freemyer@gmail.com
- correct "Provides: pyfsntfs" line, erroneously said pylnk previously
* Wed Dec  2 2015 Greg.Freemyer@gmail.com
- initial version in OBS - v0~20151130
